@@ -1,4 +1,4 @@
-/* $Id: proto.h,v 4.10 1999/10/15 22:47:54 svenske Exp $
+/* $Id: proto.h,v 4.12 2000/05/03 19:51:38 bert Exp $
  *
  * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-98 by
  *
@@ -201,6 +201,11 @@ int Cannon_select_weapon(int ind);
 void Cannon_aim(int ind, int weapon, int *target, int *dir);
 void Cannon_fire(int ind, int weapon, int target, int dir);
 
+/*
+ * Prototypes for command.c
+ */
+void Handle_player_command(player *pl, char *cmd);
+
 /*
  * Prototypes for player.c
  */
@@ -214,6 +219,7 @@ int Init_player(int ind, wireobj *ship);
 void Alloc_players(int number);
 void Free_players(void);
 void Update_score_table(void);
+void Reset_all_players(void);
 void Check_team_members(int);
 void Check_team_treasures(int);
 void Compute_game_status(void);
@@ -244,6 +250,7 @@ void Robot_message(int ind, const char *message);
  * Prototypes for rules.c
  */
 void Tune_item_probs(void);
+void Tune_item_packs(void);
 void Set_initial_resources(void);
 void Set_world_items(void);
 void Set_world_rules(void);
@@ -269,6 +276,8 @@ void Contact_cleanup(void);
 int Contact_init(void);
 void Contact(int fd, void *arg);
 void Queue_loop(void);
+int Queue_advance_player(char *name, char *msg);
+int Queue_show_list(char *msg);
 void Set_deny_hosts(void);
 
 /*
